==> tdepim-trinity-14.0.10.tar.xz: tdepim-trinity-14.0.10/certmanager/lib/backends/qgpgme/qgpgmedecryptverifyjob.h <==
/*
    qgpgmedecryptverifyjob.h

    This file is part of libkleopatra, the KDE keymanagement library
    Copyright (c) 2004 Klarlvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the TQt library by Trolltech AS, Norway (or with modified versions
    of TQt that use the same license as TQt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    TQt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEO_TQGPGMEDECRYPTVERIFYJOB_H__
#define __KLEO_TQGPGMEDECRYPTVERIFYJOB_H__

#include <kleo/decryptverifyjob.h>

#include "qgpgmejob.h"

#include <tqcstring.h>
#include <kdemacros.h>

namespace GpgME {
  class Error;
  class Context;
}

namespace Kleo {

  class KDE_EXPORT QGpgMEDecryptVerifyJob : public DecryptVerifyJob, private QGpgMEJob {
    Q_OBJECT
     TQGPGME_JOB
  public:
    QGpgMEDecryptVerifyJob( GpgME::Context * context );
    ~QGpgMEDecryptVerifyJob();

    /*! \reimp from DecryptVerifyJob */
    GpgME::Error start( const TQByteArray & cipherText );

    /*! \reimp from DecryptVerifyJob */
    std::pair<GpgME::DecryptionResult,GpgME::VerificationResult>
      exec( const TQByteArray & cipherText, TQByteArray & plainText );

  private slots:
    void slotOperationDoneEvent( GpgME::Context * context, const GpgME::Error & e ) {
      QGpgMEJob::doSlotOperationDoneEvent( context, e );
    }

  private:
    void doOperationDoneEvent( const GpgME::Error & e );
    void setup( const TQByteArray & );
  };

}

#endif // __KLEO_TQGPGMEDECRYPTVERIFYJOB_H__

==> tdepim-trinity_14.1.5.orig.tar.xz: tdepim-trinity-14.1.5/certmanager/lib/backends/qgpgme/qgpgmedecryptverifyjob.h <==
/*
    qgpgmedecryptverifyjob.h

    This file is part of libkleopatra, the KDE keymanagement library
    Copyright (c) 2004 Klarlvdalens Datakonsult AB

    Libkleopatra is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Libkleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the TQt library by Trolltech AS, Norway (or with modified versions
    of TQt that use the same license as TQt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    TQt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEO_TQGPGMEDECRYPTVERIFYJOB_H__
#define __KLEO_TQGPGMEDECRYPTVERIFYJOB_H__

#include <kleo/decryptverifyjob.h>

#include "qgpgmejob.h"

#include <tqcstring.h>
#include <tdemacros.h>

namespace GpgME {
  class Error;
  class Context;
}

namespace Kleo {

  class TDE_EXPORT QGpgMEDecryptVerifyJob : public DecryptVerifyJob, private QGpgMEJob {
    TQ_OBJECT
     TQGPGME_JOB
  public:
    QGpgMEDecryptVerifyJob( GpgME::Context * context );
    ~QGpgMEDecryptVerifyJob();

    /*! \reimp from DecryptVerifyJob */
    GpgME::Error start( const TQByteArray & cipherText );

    /*! \reimp from DecryptVerifyJob */
    std::pair<GpgME::DecryptionResult,GpgME::VerificationResult>
      exec( const TQByteArray & cipherText, TQByteArray & plainText );

  private slots:
    void slotOperationDoneEvent( GpgME::Context * context, const GpgME::Error & e ) {
      QGpgMEJob::doSlotOperationDoneEvent( context, e );
    }

  private:
    void doOperationDoneEvent( const GpgME::Error & e );
    void setup( const TQByteArray & );
  };

}

#endif // __KLEO_TQGPGMEDECRYPTVERIFYJOB_H__
